# wbib.wbib

A set of core functions that may be called from wbib.
Other modules will contain the specific queries and auxiliary functions.

Typical usage example:
```python
    qids = ["Q35185544", "Q34555562", "Q21284234"]
```
```
    render_dashboard(info=qids, mode="basic")
```
**render_dashboard()**

::: wbib.wbib.render_dashboard

**convert_doi_to_qid()**

:::wbib.wbib.convert_doi_to_qid

